/****************************************************************************
**
** Copyright (C) 2023 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  hal_ll_pps_connection_defs.h
 * @brief This file contains pps maps per chip for LOW LEVEL HAL PPS implementation.
 */

#ifndef _HAL_LL_PPS_CONNECTION_DEFS_H_
#define _HAL_LL_PPS_CONNECTION_DEFS_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include "hal_ll_pps_struct_def.h"

// -------------------------------------------------------------

/*!< @brief PPS INPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_input_map[] =
{
    #ifdef __RA0_CN
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x00, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x00, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x00, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RA1_CN
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x00, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RA2_CN
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x00, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RA3_CN
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x00, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RA4_CN
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x10, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RA5_CN
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x01, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RA6_CN
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RA7_CN
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x02, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RB0_CN
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x02, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x20, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RB1_CN
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x02, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RB2_CN
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RB3_CN
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RB4_CN
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x03, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x03, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RB5_CN
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RC2_CN
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x02, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RC3_CN
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x03, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RC4_CN
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RC5_CN
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x04, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x04, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RC6_CN
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RC7_CN
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x04, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RD0_CN
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x05, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x05, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x50, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RD1_CN
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RD2_CN
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RD3_CN
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x05, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RD4_CN
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x06, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x06, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x60, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RD5_CN
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RD6_CN
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RD7_CN
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x06, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RE0_CN
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x07, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x07, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x70, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RE1_CN
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x07, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RE2_CN
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x07, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RE3_CN
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x08, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RE4_CN
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x08, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x80, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RE5_CN
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x09, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR12_13_ADDRESS },
    #endif
    #ifdef __RE6_CN
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x08, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RE7_CN
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x07, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RF2_CN
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x09, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x09, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0x90, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RF5_CN
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RF6_CN
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0A, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0A, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0xA0, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif
    #ifdef __RF7_CN
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x09, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RG0_CN
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RG1_CN
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x09, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RG2_CN
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR2_3_ADDRESS },
    #endif
    #ifdef __RG3_CN
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0A, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR0_1_ADDRESS },
    #endif
    #ifdef __RG4_CN
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR4_5_ADDRESS },
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR6_7_ADDRESS },
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0xB0, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR8_9_ADDRESS },
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

/*!< @brief PPS OUTPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_output_map[] =
{
    #ifdef __RA0_CN
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_0, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR0_1_ADDRESS },
    #endif
    #ifdef __RA1_CN
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR0_1_ADDRESS },
    { PIN_1, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR0_1_ADDRESS },
    #endif
    #ifdef __RA2_CN
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR2_3_ADDRESS },
    { PIN_2, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_3_ADDRESS },
    #endif
    #ifdef __RA3_CN
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_3_ADDRESS },
    { PIN_3, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_3_ADDRESS },
    #endif
    #ifdef __RA4_CN
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_4, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR4_5_ADDRESS },
    #endif
    #ifdef __RA5_CN
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR4_5_ADDRESS },
    { PIN_5, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR4_5_ADDRESS },
    #endif
    #ifdef __RA6_CN
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR6_7_ADDRESS },
    { PIN_6, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_7_ADDRESS },
    #endif
    #ifdef __RA7_CN
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR10_11_ADDRESS },
    { PIN_7, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_11_ADDRESS },
    #endif
    #ifdef __RB0_CN
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR8_9_ADDRESS },
    #endif
    #ifdef __RB1_CN
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR8_9_ADDRESS },
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR8_9_ADDRESS },
    #endif
    #ifdef __RB2_CN
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR14_15_ADDRESS },
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_15_ADDRESS },
    #endif
    #ifdef __RB3_CN
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_7_ADDRESS },
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_7_ADDRESS },
    #endif
    #ifdef __RB4_CN
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR12_13_ADDRESS },
    #endif
    #ifdef __RB5_CN
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR12_13_ADDRESS },
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR12_13_ADDRESS },
    #endif
    #ifdef __RC2_CN
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_11_ADDRESS },
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_11_ADDRESS },
    #endif
    #ifdef __RC3_CN
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_15_ADDRESS },
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_15_ADDRESS },
    #endif
    #ifdef __RC4_CN
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR16_17_ADDRESS },
    #endif
    #ifdef __RC5_CN
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR16_17_ADDRESS },
    { PIN_5, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR16_17_ADDRESS },
    #endif
    #ifdef __RC6_CN
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR18_19_ADDRESS },
    { PIN_6, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR18_19_ADDRESS },
    #endif
    #ifdef __RC7_CN
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR18_19_ADDRESS },
    { PIN_7, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR18_19_ADDRESS },
    #endif
    #ifdef __RD0_CN
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR20_21_ADDRESS },
    #endif
    #ifdef __RD1_CN
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR20_21_ADDRESS },
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR20_21_ADDRESS },
    #endif
    #ifdef __RD2_CN
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR22_23_ADDRESS },
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR22_23_ADDRESS },
    #endif
    #ifdef __RD3_CN
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR22_23_ADDRESS },
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR22_23_ADDRESS },
    #endif
    #ifdef __RD4_CN
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR24_25_ADDRESS },
    #endif
    #ifdef __RD5_CN
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR24_25_ADDRESS },
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR24_25_ADDRESS },
    #endif
    #ifdef __RD6_CN
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR26_27_ADDRESS },
    { PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR26_27_ADDRESS },
    #endif
    #ifdef __RD7_CN
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR26_27_ADDRESS },
    { PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR26_27_ADDRESS },
    #endif
    #ifdef __RE0_CN
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR28_29_ADDRESS },
    #endif
    #ifdef __RE1_CN
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR28_29_ADDRESS },
    { PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR28_29_ADDRESS },
    #endif
    #ifdef __RE2_CN
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR30_31_ADDRESS },
    { PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR30_31_ADDRESS },
    #endif
    #ifdef __RE3_CN
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR32_33_ADDRESS },
    #endif
    #ifdef __RE4_CN
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR32_33_ADDRESS },
    { PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR32_33_ADDRESS },
    #endif
    #ifdef __RE5_CN
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x30, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x90, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR36_37_ADDRESS },
    #endif
    #ifdef __RE6_CN
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR34_35_ADDRESS },
    { PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR34_35_ADDRESS },
    #endif
    #ifdef __RE7_CN
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR30_31_ADDRESS },
    { PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR30_31_ADDRESS },
    #endif
    #ifdef __RF2_CN
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR36_37_ADDRESS },
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR36_37_ADDRESS },
    #endif
    #ifdef __RF5_CN
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR34_35_ADDRESS },
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR34_35_ADDRESS },
    #endif
    #ifdef __RF6_CN
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR40_41_ADDRESS },
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR40_41_ADDRESS },
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR40_41_ADDRESS },
    #endif
    #ifdef __RF7_CN
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR38_39_ADDRESS },
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR38_39_ADDRESS },
    #endif
    #ifdef __RG0_CN
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR46_ADDRESS },
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR46_ADDRESS },
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR46_ADDRESS },
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR46_ADDRESS },
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR46_ADDRESS },
    #endif
    #ifdef __RG1_CN
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR38_39_ADDRESS },
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR38_39_ADDRESS },
    #endif
    #ifdef __RG2_CN
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_10,HAL_LL_RPOR42_43_ADDRESS },
    { PIN_2, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR42_43_ADDRESS },
    #endif
    #ifdef __RG3_CN
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x30, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR42_43_ADDRESS },
    { PIN_3, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x50, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR42_43_ADDRESS },
    #endif
    #ifdef __RG4_CN
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR44_45_ADDRESS },
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR44_45_ADDRESS },
    { PIN_4, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,  0x0A, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR44_45_ADDRESS },
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

#ifdef __cplusplus
}
#endif

#endif // _HAL_LL_PPS_CONNECTION_DEFS_H_
// ------------------------------------------------------------------------- END
